/*    DP4 version 4.6210Declarations for DP4 C API      91250002432318C79FD34E 
$Log: dp4dbflg.h $
Revision 1.4  2004/10/05 11:02:34Z  Alun
Added FILE_SERVER_ONLY and LOCAL_ONLY database open modes
Revision 1.3  2003/08/06 09:37:31Z  Alun
Added macros for Terabase
Revision 1.2  2002/09/24 14:15:13Z  Alun
NULL_TIME changed to avoid C++ warnings
Revision 1.1  2002/08/23 10:28:19Z  Alun
Initial revision
*/

#ifndef DP4DBFLG_INCLUDED
#define DP4DBFLG_INCLUDED

#define DP4_INVALID_PTR  ((dp4_file_pointer)-1)
#define DP4_INVALID_SIZE  ((dp4_file_size)-1)
#define DP5_INVALID_PTR  ((dp5_file_pointer)-1)
#define DP5_INVALID_SIZE  DP5_INVALID_PTR

/* real number systems */
#define N_IEEE    0
#define N_MTPLUS  1
#define N_BASIC   2
#define N_COBOL   3
#define N_LONGINT 5
#define N_4680    6
#define N_VAX     7

#ifdef VAX_PROCESSOR
#define N_C N_VAX
#else
#define N_C N_IEEE
#endif

#ifndef TRUE
#define TRUE 1
#define FALSE 0
#endif

/* Flags for dp4_error */
#define DP4ERR_REPORT 1
#define DP4ERR_HALT   2

#define DEFAULT 0

#define T_DATA_SIZE 4096        /* max size of terminal manager data area */
#define MAX_BLK_FTCH 100
#define TEXT_HSIZE     (3+sizeof(short))
#define KEYSIZE 200

/* null values */
#define NULL_CHAR   '\0'
#define NULL_DATE   {0,'\0','\0'}
#define NULL_SHORT  ((short)0x8000)
#define NULL_USHORT  ((unsigned short)0xffff)
#define NULL_LONG   0x80000000L
#define NULL_TIME   {(unsigned char)'\377',(unsigned char)'\377',(unsigned char)'\377',(unsigned char)'\377'}

#define NULL_DOUBLE -1E300
#define MIN_DOUBLE  -5E299

/* flags to pass to db_open() */
#define SHARED           0
#define READ_ONLY        1
#define EXCLUSIVE        2
#define QUIT_ON_FAILURE  4
#define NO_LOGGING       8
#define SYSTEM           16
#define NO_ROLLBACK      32
#define RETRIEVE_ENABLE  64
#define FORCE_ENTRY      256
#define PRIVATE_DB       512
#define MISSING_OK       1024
#define DBO_RECOVER      2048
#define BIG_TRANSACTIONS 4096
#define FILE_SERVER_ONLY 8192
#define LOCAL_ONLY       16384

/* index number to use when fetching record on physical index */
#define PHYSREC_TYPE 22

/* flags to pass to bf_open() */
#define BF_SEQUENTIAL 0
#define BF_INTERACTIVE 1
#define BF_VAR_INTERACTIVE 2

/* flags to pass to rec_fetch() and similar functions*/
#define EQUAL       1
#define NEXT        2
#define PREV        4
#define BUT         8
#define NEXT_BUT    10
#define PREV_BUT    12
#define DEPTH       16
#define NEXT_DEPTH  18
#define PREV_DEPTH  20
#define FIRST       32
#define FIRST_BUT   40
#define FIRST_DEPTH 48
#define LAST        4096
#define LAST_BUT    4104
#define LAST_DEPTH  4112

#define NO_DATA     64
#define NO_UPDATE   128
#define NO_READ     256
#define NO_FINDLIST 512

#define LOCK        1024
#define UNLOCK      2048
#define REVERSE     8192

/* flag used by rec_fetch() and rec_post() etc */
#define LOCN_OVERRIDE 16384

/* flag used by QAB for post() verify() kill() and checkpoint() */
#define Q_RESET_DEFAULT 8192

/* flags to pass to rec_verify() and rec_post() */
#define NO_CHECK      0
#define CHECK_PARENT  1
#define VERIFY_PARENT 2
#define CHECK_CHANGE  8
#define POST_UNCHANGED 128 /* Makes sure record gets timestamp updated */
#define NO_AUTOINC    256

/* flags to pass to rec_kill() */
#define IGNORE_CHILD 0
#define ORPHAN_CHECK 4
#define CHILD_DELETE 8
#define NO_UPD_CHILD 256

/* flags to pass to db_update() */
#define COMMIT        0
#define CHECKPOINT    1
#define FLUSH_LOG     2
#define UNLOCK_IF_OK  4
#define UNLOCK_ALWAYS 8
#define FAIL_IF_ERROR 16
#define MSGE_IF_ERROR 32
#define CHECK_ONLY    16384
#define UPDATE_ONLY   ((int)-32768)

/* value returned by db_update */
#define COMMIT_FAILURE 3
#define LOCK_FAILURE   5
#define COMMS_FAILURE  6
#define SYSTEM_FAILURE 7

/* modes for sf_open() (and tf_open()) */
#define VF_RO  0
#define VF_RW  1
#define VF_SEQ 2   /* only maintain one buffer for file - beware!*/
#define VF_TMP 4
#define VF_SHR 8
#define VF_CKS 16  /*maintain checksum onfo - only for sf_open */
#define VF_RET 32  /*return neg file handle on error instead of failing*/
#define VF_NEW 64  /*delete file if already existing */
#define VF_NOBLK 128 /*suppresses normal blocking operations */
#define VF_SYNC 256  /*enables write through to OS bypassing buffers*/
#define VF_BATCH 512 /*alternate buffer strategy - good on sequential writes!*/
#define VF_TRACE 1024 /* reserved */
#define VF_STACK 2048 /* reserved */
#define VF_MKDIR 4096 /* Ensure directory for file exists - 32 bit tf_open() only */
#define VF_SORT   8192 /* keep buffers sorted by address */
#define VF_BIG   16384 /* Use bigger buffers for file */

/* operating system codes */
#define OS_MSDOS   2
#define OS_UNIX    4
#define OS_286     16
#define OS_2       64
#define OS_WINDOWS 128
#define OS_NOVELL  256
#define OS_PM      512

#endif
