/*    DP4 version 4.6210Header file for network programs912500024323185BA28D67 
$Log: network.h $
Revision 1.15  2004/10/05 09:18:17Z  Alun
Added STAY_OFFLINE status to allow us to keep a server offline
Revision 1.14  2003/08/05 17:42:44Z  Alun
No longer includes so many other files
Revision 1.13  2002/12/06 12:35:41Z  Alun
Use extended form of #pragma pack() if available
Revision 1.12  2001/04/03 13:22:38Z  Alun
Reworked routable networking enhancement
Revision 1.11  2000/10/11 10:51:04  Alun
Added #pragma pack(1) so can compile without Zp1
Revision 1.10  2000/07/20 11:03:50  Alun
Added remote files flag so we can tell whether -local option is OK
for REORGDB and DBCHECK
Revision 1.9  1999/03/22 16:10:58  Alun
All networking code drastically tidied up
Revision 1.7  1996/11/11 14:20:30  Alun
Added protocol checking stuff
Revision 1.6  1996/11/07 10:54:54  Alun
Updated to use standardised scheme for timeouts
Revision 1.5  1996/10/30 12:56:02  sw
Change TOUT_UNLOCK 1/2 to 1/3 timeout to fix unix keepalive scheme. Added 
definition of TOUT_LOCK.
*/

#ifndef NETWORK_INCLUDED
#define NETWORK_INCLUDED 1
/* network-independent error codes used in NTB2, NTBMGR etc */
#define NET_NOSERV 0x100 /* server not loaded */
#define NET_NORSRC 0x101 /* out of resources */
#define NET_NORPLY 0x102 /* no reply from server */
#define NET_NOINIT 0x103 /* application has not logged on to server */
#define NET_OVRRUN 0x104 /* too much data received */
#define NET_UNDRUN 0x105 /* more data to be received */
#define NET_NORQST 0x106 /* requester has disappeared */
#define NET_SRVBSY 0x107 /* server is busy */
#define NET_BADRPY 0x108 /* corrupted reply */
#define NET_PWFAIL 0x109 /* power failure */
#define NET_LOGOFF 0x10a /* requester logged off */
#define NET_IPC_ERROR 0x10b /* Local error talking to requester */
#define NET_BADVER 0x10c /* Incompatible client & server software */
#define NET_UNKNOWN 0x10d /* Can't locate server machine */

/* the netbios version requires MAX_CHANNELS >= 256 */
#define MAX_CHANNELS 256 /* max number of network sessions supported */
#define PREFIX_SIZE 256  /* max size of prefix table in network layout record */
#define MAXSERVERS   32  /* max number of servers per table */

/**
TOUT_SERVER is max time server can wait between starting to receive message and
finishing sending the reply
TOUT_RQSTR is max time requester can wait between starting to send message and
finishing receiving the reply
TOUT_UNLOCK is interval between keep-awake replies sent by a locked server
to other requesters waiting to lock it.
TOUT_LOCK is the maximum interval between processing a start checkpoint
message and receiving the end checkpoint message. If no end checkpoint message
is received within this interval the lock is broken and the client logged off
Timeouts for server, unlock, requester must obey the following restriction:
	TOUT_UNLOCK < TOUT_SERVER < TOUT_RQSTR < TOUT_LOCK

It must be assumed that each timeout can vary by +- 1 second from its nominal
value

TOUT_STATUS is the time for which status information on other servers is kept
**/

#define TOUT_DEFAULT         10
#define TOUT_UNLOCK(timeout) (timeout/3)
#define TOUT_SERVER(timeout) ((timeout*3)/4)
#define TOUT_RQSTR(timeout)  timeout
#define TOUT_SETUP(timeout)  (timeout*2)
#define TOUT_LOCK(timeout)   ((timeout*5)/2)
#define TOUT_STATUS          120


#define DP4_AUXDISTR_VER '\2'
#define DP4_NET_VER '\3'

#define _NETWORK 31
#define _NET_STATUS 44

#ifndef DP4TYPES_INCLUDED
#include "dp4types.h"
#endif

#ifdef HAVE_PACK_PRAGMA
#ifdef HAVE_PACK_PUSH
#pragma pack(push)
#endif
#pragma pack(1)
#endif

struct NETWORK /* type 31 */
{
  short l;
  short typenr;
  short generation;
  short flags;
  long timestamp;

  short number;
  struct
  {
    short number;
  } parent;
  struct
  {
    short number;
  } role;
  boolean old;
  boolean pad1;
  short dtype;
  short machine[MAXSERVERS];
  short net_spare;
  short vital_machines;
  boolean local;
  boolean pad2;
  short nr_machines;
  short nr_prefixes;
  short prefix_size;

  char prefixes[PREFIX_SIZE];
};

struct NET_STATUS /* type 44 */
{
  short l;
  short typenr;
  short generation;
  short flags;
  long timestamp;

  struct
  {
    short server;
  } info_from;
  struct
  {
    short server;
  } info_about;

  short net_mode;
  short err_mode;
  short resil_type;
  short file_server;
  short block_fetch;
  short remote_files;
  short ns_spare;
  struct
  {
    short server;
  } this_machine;
};

#ifdef HAVE_PACK_PRAGMA
#pragma pack()
#ifdef HAVE_PACK_PUSH
#pragma pack(pop)
#endif
#endif

#define ONLINE 1
#define OFFLINE 2
#define STAY_OFFLINE 3

extern unsigned long pascal to_start_timeout __P((void));
extern BOOLEAN pascal to_timed_out __P((unsigned long start,int tout));
/* Call network database manager */
struct SRV_PARA;
extern void pascal srv_net_call __P((struct SRV_PARA DP4P para,ANY DP4P data0,ANY DP4P data1));
#endif
